<?php

namespace Pinpoint\Faq\Model\Config\Source;

use Magento\Framework\Option\ArrayInterface;

/**
 * Class Store
 * @package Pinpoint\Faq\Model\Config\Source
 */
class Store implements ArrayInterface
{
    /**
     * @var \Magento\Store\Model\System\Store
     */
    protected $_systemStore;

    /**
     * Store constructor.
     * @param \Magento\Store\Model\System\Store $systemStore
     */
    public function __construct(
        \Magento\Store\Model\System\Store $systemStore
    ) {
        $this->_systemStore = $systemStore;
    }

    /**
     * @return array
     */
    public function toOptionArray()
    {
        $result = [];
        foreach ($this->getOptions() as $value => $label) {
            $result[] = [
                'value' => $value,
                'label' => $label,
            ];
        }
        return $result;
    }

    /**
     * @return array
     */
    public function getOptions()
    {
        $array = ['0' => 'All Websites'];
        $websites = $this->_systemStore->getStoreValuesForForm(false, false);
        $nonEscapableNbspChar = html_entity_decode('&#160;', ENT_NOQUOTES, 'UTF-8');
        foreach ($websites as $website) {
            if (is_array($website['value']) && count($website['value']) > 0) {
                foreach ($website['value'] as $store) {
                    $websiteLabel = str_replace($nonEscapableNbspChar, "", $website['label']);
                    $storeLabel = str_replace($nonEscapableNbspChar, "", $store['label']);
                    $array[$store['value']] = __($websiteLabel).' - '.__($storeLabel);
                }
            }
        }
        return $array;
    }
}
